@@ -6,10 +6,14 @@ class AbstractArticle:
 
     subject = ""
     body = ""
+    df = ""
 
     def call(self):
-        return Article({
+        self.article_params = {
             "Subject": self.subject,
             "Body": self.body,
-            "ContentType": "text/plain; charset=utf8"
-        })
+            "ContentType": "text/plain; charset=utf8",
+            "DynamicField": self.df
+        }
+
+        return Article(self.article_params)
