@@ -2,6 +2,8 @@ import requests
 import os
 import json
 
+from otrs_somconnexio.exceptions import ErrorSettingPreference
+
 
 class UserManagementClient:
     WEBSERVICES_PATH = 'otrs/nph-genericinterface.pl/Webservice/UserManagement/cuser'
@@ -33,4 +35,11 @@ class UserManagementClient:
         }
         json_payload = json.dumps(payload)
         url = '{}{}'.format(cls._url(), cls.WEBSERVICES_PATH)
-        requests.post(url, data=json_payload)
+        response = requests.post(url, data=json_payload)
+
+        # TODO: We ask to change the behaviour of this endpoint.
+        # Raise an error and return a status 200 it's not a good idea.
+        if response.json()['Result'] == []:
+            raise ErrorSettingPreference(
+                "Error setting the language code {} to user {}".format(lang, user_id)
+            )
