@@ -16,6 +16,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
         party = Mock(spec=[
             'get_identifier',
             'get_contact_email',
+            'get_contact_phone',
             'first_name',
             'name'
         ])
@@ -29,7 +30,8 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'mobile_icc_number',
             'mobile_min',
             'mobile_internet',
-            'mobile_option'
+            'mobile_option',
+            'mobile_telecom_company'
         ])
         eticom_contract.id = 123
         eticom_contract.party = party
