@@ -16,7 +16,8 @@ class InternetArticleTestCase(unittest.TestCase):
         expected_article_arguments = {
             "Subject": "Sol·licitud fibra 123",
             "Body": "",
-            "ContentType": "text/plain; charset=utf8"
+            "ContentType": "text/plain; charset=utf8",
+            "DynamicField": ""
         }
 
         InternetArticle(service_type, eticom_contract).call()
