@@ -16,7 +16,8 @@ class MobileArticleTestCase(unittest.TestCase):
         expected_article_arguments = {
             "Subject": "Sol·licitud mobile 123",
             "Body": "",
-            "ContentType": "text/plain; charset=utf8"
+            "ContentType": "text/plain; charset=utf8",
+            "DynamicField": ""
         }
 
         MobileArticle(service_type, eticom_contract).call()
