@@ -12,7 +12,8 @@ class MobileTicketTestCase(unittest.TestCase):
     def test_build_ticket(self, MockTicket):
         party = Mock(spec=[
             'get_contact_email',
-            'get_identifier'
+            'get_identifier',
+            'get_contact_phone'
         ])
         email = Mock(spec=['value'])
         email.value = 'contact@mail.com'
@@ -20,6 +21,9 @@ class MobileTicketTestCase(unittest.TestCase):
         vat = Mock(spec=['code'])
         vat.code = 'VatCode'
         party.get_identifier.return_value = vat
+        phone = Mock(spec=['value'])
+        phone.value = '666666666'
+        party.get_contact_phone.return_value = phone
 
         eticom_contract = Mock(spec=[
             'id',
@@ -35,7 +39,7 @@ class MobileTicketTestCase(unittest.TestCase):
             'mobile_ticket_priority',
             'mobile_process_id',
             'mobile_activity_id',
-            ])
+        ])
         otrs_configuration.mobile_ticket_type = 'mobile_ticket_type'
         otrs_configuration.mobile_ticket_queue = 'mobile_ticket_queue'
         otrs_configuration.mobile_ticket_state = 'mobile_ticket_state'
@@ -77,7 +81,7 @@ class MobileTicketTestCase(unittest.TestCase):
             'mobile_ticket_priority',
             'mobile_process_id',
             'mobile_activity_id',
-            ])
+        ])
         otrs_configuration.mobile_ticket_type = 'mobile_ticket_type'
         otrs_configuration.mobile_ticket_queue = 'mobile_ticket_queue'
         otrs_configuration.mobile_ticket_state = 'mobile_ticket_state'
@@ -104,7 +108,7 @@ class MobileTicketTestCase(unittest.TestCase):
             'mobile_ticket_priority',
             'mobile_process_id',
             'mobile_activity_id',
-            ])
+        ])
         otrs_configuration.mobile_ticket_type = 'mobile_ticket_type'
         otrs_configuration.mobile_ticket_queue = 'mobile_ticket_queue'
         otrs_configuration.mobile_ticket_state = 'mobile_ticket_state'
@@ -163,10 +167,12 @@ class MobileTicketTestCase(unittest.TestCase):
             'mobile_min',
             'mobile_internet',
             'mobile_option',
+            'mobile_telecom_company',
         ])
         eticom_contract.party = Mock(spec=[
             'get_identifier',
             'get_contact_email',
+            'get_contact_phone',
             'first_name',
             'name',
         ])
