@@ -2,8 +2,9 @@
 import os
 import unittest
 import json
-from mock import patch
+from mock import Mock, patch
 
+from otrs_somconnexio.exceptions import ErrorSettingPreference
 from otrs_somconnexio.user_management_client.client import UserManagementClient
 
 USER = 'user'
@@ -11,13 +12,13 @@ PASSW = 'passw'
 URL = 'https://otrs-url.coop/'
 
 
+@patch.dict(os.environ, {
+    'OTRS_USER': USER,
+    'OTRS_PASSW': PASSW,
+    'OTRS_URL': URL
+})
 class UserManagementClientTestCase(unittest.TestCase):
 
-    @patch.dict(os.environ, {
-        'OTRS_USER': USER,
-        'OTRS_PASSW': PASSW,
-        'OTRS_URL': URL
-    })
     @patch('otrs_somconnexio.user_management_client.client.requests', spec=['post'])
     def test_set_user_preference(self, requests_mock):
         user_id = 'test@test.test'
@@ -36,7 +37,21 @@ class UserManagementClientTestCase(unittest.TestCase):
                 "UserID": user_id
             }
         }
+        requests_mock.post.return_value = Mock(spec=['json'])
+        requests_mock.post.return_value.json.return_value = {"Result": [1]}
 
         UserManagementClient().set_preference(preference_key, user_id, lang)
 
         requests_mock.post.assert_called_once_with(expected_url, data=json.dumps(expected_body))
+
+    @patch('otrs_somconnexio.user_management_client.client.requests', spec=['post'])
+    def test_set_user_preference_raise_error_if_fails(self, requests_mock):
+        user_id = 'test@test.test'
+        lang = 'es'
+        preference_key = 'UserLanguage'
+
+        requests_mock.post.return_value = Mock(spec=['json'])
+        requests_mock.post.return_value.json.return_value = {"Result": []}
+
+        with self.assertRaises(ErrorSettingPreference):
+            UserManagementClient().set_preference(preference_key, user_id, lang)
